==> v1.0.13.zip: smartpdf/readme.md <==
# @pushrocks/smartpdf
Create PDFs fast and smoothly

## Availabililty and Links
* [npmjs.org (npm package)](https://www.npmjs.com/package/@pushrocks/smartpdf)
* [gitlab.com (source)](https://gitlab.om/pushrocks/smartpdf)
* [github.com (source mirror)](https://github.com/pushrocks/smartpdf)
* [docs (typedoc)](https://pushrocks.gitlab.io/smartpdf/)

## Status for master
[![build status](https://gitlab.om/pushrocks/smartpdf/badges/master/build.svg)](https://gitlab.om/pushrocks/smartpdf/commits/master)
[![coverage report](https://gitlab.om/pushrocks/smartpdf/badges/master/coverage.svg)](https://gitlab.om/pushrocks/smartpdf/commits/master)
[![npm downloads per month](https://img.shields.io/npm/dm/@pushrocks/smartpdf.svg)](https://www.npmjs.com/package/@pushrocks/smartpdf)
[![Known Vulnerabilities](https://snyk.io/test/npm/@pushrocks/smartpdf/badge.svg)](https://snyk.io/test/npm/@pushrocks/smartpdf)
[![TypeScript](https://img.shields.io/badge/TypeScript->=%203.x-blue.svg)](https://nodejs.org/dist/latest-v10.x/docs/api/)
[![node](https://img.shields.io/badge/node->=%2010.x.x-blue.svg)](https://nodejs.org/dist/latest-v10.x/docs/api/)
[![JavaScript Style Guide](https://img.shields.io/badge/code%20style-prettier-ff69b4.svg)](https://prettier.io/)

## Usage

For further information read the linked docs at the top of this readme.

> MIT licensed | **&copy;** [Lossless GmbH](https://lossless.gmbh)
| By using this npm module you agree to our [privacy policy](https://lossless.gmbH/privacy.html)

[![repo-footer](https://pushrocks.gitlab.io/assets/repo-footer.svg)](https://maintainedby.lossless.com)

==> v1.0.22.zip: smartpdf/readme.md <==
# @pushrocks/smartpdf
Create PDFs fast and smoothly

## Availabililty and Links
* [npmjs.org (npm package)](https://www.npmjs.com/package/@pushrocks/smartpdf)
* [gitlab.com (source)](https://gitlab.com/pushrocks/smartpdf)
* [github.com (source mirror)](https://github.com/pushrocks/smartpdf)
* [docs (typedoc)](https://pushrocks.gitlab.io/smartpdf/)

## Status for master
[![build status](https://gitlab.com/pushrocks/smartpdf/badges/master/build.svg)](https://gitlab.com/pushrocks/smartpdf/commits/master)
[![coverage report](https://gitlab.com/pushrocks/smartpdf/badges/master/coverage.svg)](https://gitlab.com/pushrocks/smartpdf/commits/master)
[![npm downloads per month](https://img.shields.io/npm/dm/@pushrocks/smartpdf.svg)](https://www.npmjs.com/package/@pushrocks/smartpdf)
[![Known Vulnerabilities](https://snyk.io/test/npm/@pushrocks/smartpdf/badge.svg)](https://snyk.io/test/npm/@pushrocks/smartpdf)
[![TypeScript](https://img.shields.io/badge/TypeScript->=%203.x-blue.svg)](https://nodejs.org/dist/latest-v10.x/docs/api/)
[![node](https://img.shields.io/badge/node->=%2010.x.x-blue.svg)](https://nodejs.org/dist/latest-v10.x/docs/api/)
[![JavaScript Style Guide](https://img.shields.io/badge/code%20style-prettier-ff69b4.svg)](https://prettier.io/)

## Usage

For further information read the linked docs at the top of this readme.

> MIT licensed | **&copy;** [Lossless GmbH](https://lossless.gmbh)
| By using this npm module you agree to our [privacy policy](https://lossless.gmbH/privacy)

[![repo-footer](https://lossless.gitlab.io/publicrelations/repofooter.svg)](https://maintainedby.lossless.com)
